@@ -39,7 +39,7 @@ def decode_msg_1(bit_arr: bitarray.bitarray) -> Dict[str, Any]:
         'second': get_int_from_data(137, 143),
         'maneuver': ManeuverIndicator(get_int_from_data(143, 145)),
         'raim': bit_arr[148],
-        'radio': get_int_from_data(149, bit_arr.length()),
+        'radio': get_int_from_data(149, len(bit_arr)),
     }
 
 
@@ -532,7 +532,7 @@ def decode_msg_24(bit_arr: bitarray.bitarray) -> Dict[str, Any]:
             'to_stern': get_int_from_data(141, 150),
             'to_port': get_int_from_data(150, 156),
             'to_starboard': get_int_from_data(156, 162),
-            'mothership_mmsi': get_int_from_data(132, 162)
+            'mothership_mmsi': get_mmsi(bit_arr, 132, 162)
         }
     data.update(d)
     return data
