@@ -4,6 +4,7 @@ from typing import Any, Dict, Optional, Sequence
 from bitarray import bitarray  # type: ignore
 
 from pyais.ais_types import AISType
+from pyais.constants import TalkerID
 from pyais.decode import decode
 from pyais.exceptions import InvalidNMEAMessageException, InvalidChecksumException
 from pyais.util import decode_into_bit_array, get_int, compute_checksum
@@ -53,7 +54,8 @@ class NMEAMessage(object):
         ) = values
 
         # The talker is identified by the next 2 characters
-        self.talker: str = head[1:3].decode('ascii')
+        talker: str = head[1:3].decode('ascii')
+        self.talker: TalkerID = TalkerID(talker)
 
         # The type of message is then identified by the next 3 characters
         self.msg_type: str = head[3:].decode('ascii')
@@ -148,13 +150,14 @@ class NMEAMessage(object):
 
         @param silent: Boolean. If set to true errors are ignored and None is returned instead
         """
+        msg = AISMessage(self)
         try:
-            return AISMessage(self)
+            msg.decode()
         except Exception as e:
-            if silent:
-                return None
+            if not silent:
+                raise e
 
-            raise e
+        return msg
 
 
 class AISMessage(object):
@@ -163,8 +166,15 @@ class AISMessage(object):
     """
 
     def __init__(self, nmea_message: NMEAMessage) -> None:
+        """Creates an initial empty AIS message"""
         self.nmea: NMEAMessage = nmea_message
-        self.msg_type: AISType = AISType(nmea_message.ais_id)
+        self.msg_type: AISType = AISType.NOT_IMPLEMENTED
+        self.content: Dict[str, Any] = {}
+
+    def decode(self) -> None:
+        """Decodes the given message and extracts it's type and content.
+        This function potentially fails, if the message is malformed."""
+        self.msg_type = AISType(self.nmea.ais_id)
         self.content = decode(self.nmea)
 
     def __getitem__(self, item: str) -> Any:
