@@ -469,7 +469,7 @@ class TestAIS(unittest.TestCase):
         assert msg['to_stern'] == 0
         assert msg['to_port'] == 0
         assert msg['to_starboard'] == 0
-        assert msg['mothership_mmsi'] == 0
+        assert msg['mothership_mmsi'] == "000000000"
 
     def test_msg_type_25(self):
         msg = NMEAMessage(b"!AIVDM,1,1,,A,I6SWo?8P00a3PKpEKEVj0?vNP<65,0*73").decode()
@@ -557,5 +557,23 @@ class TestAIS(unittest.TestCase):
         with self.assertRaises(UnknownMessageException):
             nmea.decode(silent=False)
 
-        # by default errors are ignored and None is returned
-        assert nmea.decode() is None
+        # by default errors are ignored and an empty AIS message is returned
+        assert nmea.decode() is not None
+        assert isinstance(nmea.decode(), AISMessage)
+        text = """{
+    "nmea": {
+        "ais_id": 37,
+        "raw": "!AIVDM,1,1,,A,U31<0OOP000CshrMdl600?wP00SL,0*43",
+        "talker": "AI",
+        "msg_type": "VDM",
+        "count": 1,
+        "index": 1,
+        "seq_id": "",
+        "channel": "A",
+        "data": "U31<0OOP000CshrMdl600?wP00SL",
+        "checksum": 67,
+        "bit_array": "100101000011000001001100000000011111011111100000000000000000000000010011111011110000111010011101101100110100000110000000000000001111111111100000000000000000100011011100"
+    },
+    "decoded": {}
+}"""
+        assert nmea.decode().to_json() == text
